%% DATA %%
%
% Display the data from Bp12_294a_2212_2215.mat. The data corresponds to
% Figure 2A from Goldbogen et al. (2014) courtesy of Alison Stimpert. The
% data is of a 3 s window from 22:12 to 22:15.
%
% Alison Stimpert: astimpert@mlml.calstate.edu
% Jeremy Goldbogen: jergold@stanford.edu

set(0,'DefaultAxesFontSize',16);
cmap = get(gca,'ColorOrder');

% Load data
% acou = acoustic data. Sampled at 1200 Hz
% x, y, z = accelerometer data. Sampled at 200 Hz
load Bp12_294a_2212_2215.mat;
f = 1200; % acoustic sampling rate
tmin = 0;
tmax = 3;
t = linspace(0,3,f*(tmax-tmin));

%figHandle = figure; clf;
%set(figHandle,'Position',[100 100 600 400])
subplot(3,1,1);
r = 1;
plot(t, acou * 1e-5 * r, 'Color', cmap(4,:));
ylabel('\Delta p (bar m)');

% cwt
[wt, f] = cwt(acou, f);
[m,n] = size(wt);
subplot(3,1,2:3);
pcolor(repmat(t,m,1), repmat(f,1,n), abs(wt));
shading interp;
ylim([2 50]);
ylabel('Frequency (Hz)');
xlabel('Time (s)');

print('acousticData','-dpdf','-r0');

    
    
    
    
    
    
