%% Plot different seismic sources and whales on same plot

set(0,'DefaultLineLineWidth',1.5');
set(0,'DefaultAxesFontSize',16);

figHandle = figure; clf;
set(figHandle,'Position',[100 100 600 800])

%% Seismic Airgun - Single %%

ref = 1e-6;
b = load('SingleAirgun');
subplot(2,1,1);
plot(b(:,1), b(:,2)/1000); hold on;
xlim([0 1]);

[fb, B] = FourierTransform(b(:,1), b(:,2)/1000);
subplot(2,1,2);
plot(fb, mag2db(abs(B)/ref)); hold on;

%% Seismic Airgun - Cluster %%

c = load('Cluster');
subplot(2,1,1);
plot(c(:,1), c(:,2)/1000);

[fc, C] = FourierTransform(c(:,1), c(:,2)/1000);
subplot(2,1,2);
plot(fc, mag2db(abs(C)/ref));

%% Marine Vibe %%

a = load('MarineVibe');
subplot(2,1,1); 
plot(a(:,1)-0.02, a(:,2)/100);
hold on;
xlabel('Time (s)');
ylabel('\Delta p (bar)');


[fa, A] = FourierTransform(a(:,1), a(:,2)/100);
subplot(2,1,2);
plot(fa, mag2db(abs(A)/ref));
hold on;
xlabel('Frequency (Hz)');
ylabel('Power (db)');
xlim([2 150]);

%% WHALE 
load Bp12_294a_2212_2215.mat

whaleAcou = acou(1601:2800,1);
whaleTime = linspace(0,1,length(whaleAcou));

subplot(2,1,1);
plot(whaleTime, whaleAcou*1e-5);
ylim([-6e-3 10e-3]);

[fWhale, AmpWhale] = FourierTransform(whaleTime, whaleAcou*1e-5);
subplot(2,1,2);
ylim([-20 100])
plot(fWhale, mag2db(abs(AmpWhale)/ref));

subplot(2,1,1);
legend('500 in^3 airgun at 1000 m','3 x 155 in^3 cluster at 1000 m',...
    'Marine vibroseis at 100 m','Whale tag data')

subplot(2,1,2);
legend('500 in^3 airgun at 1000 m','3 x 155 in^3 cluster at 1000 m',...
    'Marine vibroseis at 100 m','Whale tag data')

	print('compareWhalesSeismicSources','-dpdf');
