function [f, A, A2, params] = FourierTransform(t, a)
% [f, A, A2, params] = FourierTransform(t, a)
%
% Compute the Fourier Transform 
%
% INPUTS:
% t = time vector. Can be irregularly sampled
% a = amplitude of time series
%
% OUTPUTS:
% f = frequency vector
% A = real valued single sided amplitude spectrum
% A2 = complex valued double sided amplitude spectrum. Needed for inverse FT
% params = parameters. Needed for inverse FT

dt = 1e-3; % regular time spacing to interpolate onto
tInt = min(t):dt:max(t); % regular spaced time vector
aInt = pchip(t, a, tInt); % interpolate amplitudes onto regular spaced time vector

L = length(tInt); % length of signal
Fs = 1/dt + 1; % sampling frequency
Ts = 1/Fs;

Y = fft(aInt); % fast Fourier transform

A2 = Y/L; % two sided amplitude spectrum
A = A2(1:floor(L/2)+1); % single sided amplitude spectrum
A(2:end-1) = 2*A(2:end-1);
 
f = Fs*(0:(L/2))/L; % frequency vector

% save parameters
params.L = L;
params.dt = dt;
params.Fs = Fs;
params.Ts = Ts;
params.tEnd = max(t);
