%% MAKE FIG 6 %%

set(0,'DefaultAxesFontSize',16);
cmap = get(gca,'ColorOrder');

%% INITIALIZE %%

% time
time = [0 3];

% set parameters for modeling
params.rho_infty = 1000; % ambient density of water [kg/m^3]
params.c_infty = 1482; % speed of sound in water [m/s]
p_atmo = 1e5; % atmospheric pressure [Pa]
depth = 18.6; % depth of whale [m]
g = 9.8; % gravitational acceleration [m/s^2]
params.p_infty = p_atmo + params.rho_infty*g*depth; % ambient pressure at depth [Pa]
params.k = 1.4; % polytropic index. Adiabatic = 1.4
params.S = 8e4; % surface tension [N/m or kg/s^2]

% solve for equilibrium properties of lung at depth
V_atmo = 1.54; % volume of lungs at surface [m^3]
T_atmo = 293.15; % air temperature at surface [K]
T0 = 310.15; % whale body temperature at depth [K]
Q = 8.314; % universal gas constant [J/(mol K)]
n = p_atmo*V_atmo / (Q*T_atmo); % number of moles of air [mol]
params.R0 = fzero(@(R) R^3*params.p_infty + 2*params.S*R^2 - (n*Q*T0)/(4/3*pi), ...
    3*V_atmo/(4*pi));
params.p0 = params.p_infty + 2*params.S/params.R0;

% load forcing
load forcing.mat;
params.pp = pp;

% characteristic time scale of decay
tau = 2*params.R0*params.rho_infty*params.c_infty / (3*params.k*params.p0);

% resonant frequency
resFreq = (1/(2*pi)) * (1/params.R0) * ((3*params.k*params.p_infty)/params.rho_infty + ...
    (2*params.S)/(params.rho_infty*params.R0)*(3*params.k-1))^(1/2);

% initial conditions
initR = 0;
initU = 0;
initCond = [initR initU];

% solver
options = odeset('RelTol',1e-8);
sol = ode45(@governingEqnLinearForcing, time, initCond, options, params);

t = sol.x'; % time
R = sol.y(1,:)'; % radius
U = sol.y(2,:)'; % velocity
[~,solDY] = deval(sol, t);
A = solDY(2,:)'; % acceleration



% figure(1); clf;
% plot(t, A); hold on;

load Bp12_294a_2212_2215.mat;
tData = linspace(0, 3, 600);
% plot(tData, x,'--');

% continuous wavelet transform
fAccel = 200;
accelTime = linspace(min(t), max(t), (max(t)-min(t))*fAccel);
accel = pchip(t, A, accelTime);
[wt, f] = cwt(accel, fAccel);
[m, n] = size(wt);

% Generate figure
figHandle = figure; clf;
set(figHandle,'Position',[100 100 600 400])

subplot(3,1,1);
plot(t, A);
ylabel('m/s^2');

subplot(3,1,2:3);
pcolor(repmat(accelTime,m,1), repmat(f,1,n), abs(wt));
shading interp;
ylim([2 50]);
xlabel('Time (s)');
ylabel('Frequency (Hz)');


print('drivenOscillation','-dpdf');







